@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: project-template
 version: 0.2.0
-id: project-template-0.2.0-a0cacaa3cd81c3306f043b8bed66c96e
-key: proje_IAHLrDvkoWZ6rxsVeZmEgP
+id: project-template-0.2.0-eb064117f46a16a8ac5b0c44c14f0dab
+key: proje_0rTUlVHdAwN2uMITurt567
 license: BSD3
 maintainer: michael@fpcomplete.com
 homepage: https://github.com/fpco/haskell-ide
@@ -19,13 +19,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/project-template-0.2.0
-hs-libraries: HSproject-template-0.2.0-IAHLrDvkoWZ6rxsVeZmEgP
+hs-libraries: HSproject-template-0.2.0-0rTUlVHdAwN2uMITurt567
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
+    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
